==> typolight-2.6.2.tar.gz: typolight-2.6.2/system/modules/news/languages/en/default.php <==
<?php if (!defined('TL_ROOT')) die('You can not access this file directly!');

/**
 * TYPOlight webCMS
 * Copyright (C) 2005 Leo Feyer
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program. If not, please visit the Free
 * Software Foundation website at http://www.gnu.org/licenses/.
 *
 * PHP version 5
 * @copyright  Leo Feyer 2005
 * @author     Leo Feyer <leo@typolight.org>
 * @package    News
 * @license    LGPL
 * @filesource
 */


/**
 * Miscellaneous
 */
$GLOBALS['TL_LANG']['MSC']['open']         = 'Read more on %s';
$GLOBALS['TL_LANG']['MSC']['readMore']     = 'Read the whole article';
$GLOBALS['TL_LANG']['MSC']['author']       = 'Author';
$GLOBALS['TL_LANG']['MSC']['by']           = 'by';
$GLOBALS['TL_LANG']['MSC']['empty']        = 'No news items for this month.';
$GLOBALS['TL_LANG']['MSC']['published']    = 'Published';
$GLOBALS['TL_LANG']['MSC']['unpublished']  = 'Unpublished';
$GLOBALS['TL_LANG']['MSC']['addComment']   = 'Add a comment';
$GLOBALS['TL_LANG']['MSC']['comments']     = 'Comments';
$GLOBALS['TL_LANG']['MSC']['commentCount'] = '(%s comments)';

?>

==> typolight-2.6.7.tar.gz: typolight-2.6.7/system/modules/news/languages/en/default.php <==
<?php if (!defined('TL_ROOT')) die('You can not access this file directly!');

/**
 * TYPOlight webCMS
 * Copyright (C) 2005 Leo Feyer
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program. If not, please visit the Free
 * Software Foundation website at http://www.gnu.org/licenses/.
 *
 * PHP version 5
 * @copyright  Leo Feyer 2005
 * @author     Leo Feyer <leo@typolight.org>
 * @package    News
 * @license    LGPL
 * @filesource
 */


/**
 * Miscellaneous
 */
$GLOBALS['TL_LANG']['MSC']['open']         = 'Read more on %s';
$GLOBALS['TL_LANG']['MSC']['readMore']     = 'Read the whole article';
$GLOBALS['TL_LANG']['MSC']['author']       = 'Author';
$GLOBALS['TL_LANG']['MSC']['by']           = 'by';
$GLOBALS['TL_LANG']['MSC']['empty']        = 'There are no news items for this period.';
$GLOBALS['TL_LANG']['MSC']['published']    = 'Published';
$GLOBALS['TL_LANG']['MSC']['unpublished']  = 'Unpublished';
$GLOBALS['TL_LANG']['MSC']['addComment']   = 'Add a comment';
$GLOBALS['TL_LANG']['MSC']['comments']     = 'Comments';
$GLOBALS['TL_LANG']['MSC']['commentCount'] = '(%s comments)';

?>
